@@ -26,7 +26,6 @@ use warnings;
 use POSIX;
 use Fcntl;
 use File::Temp qw(tempdir tempfile);
-use File::Path qw(remove_tree);
 use File::Copy;
 
 use Dpkg::Deps;
@@ -353,6 +352,7 @@ sub dump_build_environment {
 
     my $arch = $self->get('Arch');
     my ($sysname, $nodename, $release, $version, $machine) = POSIX::uname();
+    $self->log_subsection("Build environment");
     $self->log("Kernel: $sysname $release $arch ($machine)\n");
 
     $self->log("Toolchain package versions:");
@@ -514,6 +514,24 @@ sub setup_apt_archive {
 		   tempdir('resolver' . '-XXXXXX',
 			   DIR => $self->get('Chroot Build Dir')));
     }
+    $session->run_command(
+	{ COMMAND => ['chown', $self->get_conf('BUILD_USER') . ':sbuild',
+		      $session->strip_chroot_path($self->get('Dummy package path'))],
+	  USER => 'root',
+	  DIR => '/' });
+    if ($?) {
+	$self->log_error("E: Failed to set " . $self->get_conf('BUILD_USER') .
+			 ":sbuild ownership on dummy package dir\n");
+	return 0;
+    }
+    $session->run_command(
+	{ COMMAND => ['chmod', '0770', $session->strip_chroot_path($self->get('Dummy package path'))],
+	  USER => 'root',
+	  DIR => '/' });
+    if ($?) {
+	$self->log_error("E: Failed to set 0770 permissions on dummy package dir\n");
+	return 0;
+    }
     my $dummy_dir = $self->get('Dummy package path');
     my $dummy_gpghome = $dummy_dir . '/gpg';
     my $dummy_archive_dir = $dummy_dir . '/apt_archive';
@@ -535,7 +553,17 @@ sub setup_apt_archive {
         $self->cleanup_apt_archive();
         return 0;
     }
-    if (!(-d $dummy_archive_dir || mkdir $dummy_archive_dir, 0755)) {
+    $session->run_command(
+	{ COMMAND => ['chown', $self->get_conf('BUILD_USER') . ':sbuild',
+		      $session->strip_chroot_path($dummy_gpghome)],
+	  USER => 'root',
+	  DIR => '/' });
+    if ($?) {
+	$self->log_error("E: Failed to set " . $self->get_conf('BUILD_USER') .
+			 ":sbuild ownership on $dummy_gpghome\n");
+	return 0;
+    }
+    if (!(-d $dummy_archive_dir || mkdir $dummy_archive_dir, 0775)) {
         $self->log_warning('Could not create build-depends dummy archive dir ' . $dummy_archive_dir . ': ' . $!);
         $self->cleanup_apt_archive();
         return 0;
@@ -603,6 +631,34 @@ EOF
 			      host_arch => $self->get('Arch'));
     }
 
+    $self->log("Merged Build-Depends: $positive\n") if $positive;
+    $self->log("Merged Build-Conflicts: $negative\n") if $negative;
+
+    # Filter out all but the first alternative except in special
+    # cases.
+    if (!$self->get_conf('RESOLVE_ALTERNATIVES')) {
+	my $positive_filtered = Dpkg::Deps::AND->new();
+	foreach my $item ($positive->get_deps()) {
+	    my $alt_filtered = Dpkg::Deps::OR->new();
+	    my @alternatives = $item->get_deps();
+	    my $first = shift @alternatives;
+	    $alt_filtered->add($first) if defined $first;
+	    # Allow foo (rel x) | foo (rel y) as the only acceptable
+	    # form of alternative.  i.e. where the package is the
+	    # same, but different relations are needed, since these
+	    # are effectively a single logical dependency.
+	    foreach my $alt (@alternatives) {
+		if ($first->{'package'} eq $alt->{'package'}) {
+		    $alt_filtered->add($alt);
+		} else {
+		    last;
+		}
+	    }
+	    $positive_filtered->add($alt_filtered);
+	}
+	$positive = $positive_filtered;
+    }
+
     if ($positive ne "") {
 	print DUMMY_CONTROL 'Depends: ' . $positive . "\n";
     }
@@ -610,8 +666,8 @@ EOF
 	print DUMMY_CONTROL 'Conflicts: ' . $negative . "\n";
     }
 
-    debug("DUMMY Depends: $positive \n");
-    debug("DUMMY Conflicts: $negative \n");
+    $self->log("Filtered Build-Depends: $positive\n") if $positive;
+    $self->log("Filtered Build-Conflicts: $negative\n") if $negative;
 
     print DUMMY_CONTROL <<"EOF";
 Maintainer: Debian buildd-tools Developers <buildd-tools-devel\@lists.alioth.debian.org>
@@ -621,10 +677,26 @@ Description: Dummy package to satisfy dependencies with apt - created by sbuild
 EOF
     close (DUMMY_CONTROL);
 
+    foreach my $path ($dummy_pkg_dir . '/DEBIAN/control',
+		      $dummy_pkg_dir . '/DEBIAN',
+		      $dummy_pkg_dir,
+		      $dummy_archive_dir) {
+	$session->run_command(
+	    { COMMAND => ['chown', $self->get_conf('BUILD_USER') . ':sbuild',
+			  $session->strip_chroot_path($path)],
+	      USER => 'root',
+	      DIR => '/' });
+	if ($?) {
+	    $self->log_error("E: Failed to set " . $self->get_conf('BUILD_USER')
+			   . ":sbuild ownership on $path\n");
+	    return 0;
+	}
+    }
+
     #Now build the package:
     $session->run_command(
 	{ COMMAND => ['dpkg-deb', '--build', $session->strip_chroot_path($dummy_pkg_dir), $session->strip_chroot_path($dummy_deb)],
-	  USER => $self->get_conf('USER'),
+	  USER => $self->get_conf('BUILD_USER'),
 	  PRIORITY => 0});
     if ($?) {
 	$self->log("Dummy package creation failed\n");
@@ -692,7 +764,7 @@ EOF
                        $session->strip_chroot_path($dummy_release_file));
     $session->run_command(
 	{ COMMAND => \@gpg_command,
-	  USER => $self->get_conf('USER'),
+	  USER => $self->get_conf('BUILD_USER'),
 	  PRIORITY => 0});
     if ($?) {
 	$self->log("Failed to sign dummy archive Release file.\n");
@@ -707,6 +779,15 @@ EOF
         print $tmpfh 'deb-src file://' . $session->strip_chroot_path($dummy_archive_dir) . " ./\n";
         close($tmpfh);
         # List file needs to be moved with root.
+        $session->run_command(
+            { COMMAND => ['chmod', '0644', $session->strip_chroot_path($tmpfilename)],
+              USER => 'root',
+              PRIORITY => 0});
+        if ($?) {
+            $self->log("Failed to create apt list file for dummy archive.\n");
+            $self->cleanup_apt_archive();
+            return 0;
+        }
         $session->run_command(
             { COMMAND => ['mv', $session->strip_chroot_path($tmpfilename),
                           $session->strip_chroot_path($dummy_archive_list_file)],
@@ -736,10 +817,16 @@ EOF
 # Remove the apt archive.
 sub cleanup_apt_archive {
     my $self = shift;
+
     my $session = $self->get('Session');
+
     if (defined $self->get('Dummy package path')) {
-	remove_tree($self->get('Dummy package path'));
+	$session->run_command(
+	    { COMMAND => ['rm', '-fr', $session->strip_chroot_path($self->get('Dummy package path'))],
+	      USER => $self->get_conf('BUILD_USER'),
+	      DIR => '/' });
     }
+
     $session->run_command(
 	{ COMMAND => ['rm', '-f', $session->strip_chroot_path($self->get('Dummy archive list file'))],
 	  USER => 'root',
@@ -812,7 +899,7 @@ EOF
     # Run apt-ftparchive to generate Packages and Sources files.
     $host->run_command(
         { COMMAND => ['apt-ftparchive', '-q=2', 'generate', $tmpfilename],
-          USER => $self->get_conf('USER'),
+          USER => $self->get_conf('USERNAME'),
           PRIORITY => 0,
           DIR => '/'});
     if ($?) {
@@ -824,7 +911,7 @@ EOF
     # Get output for Release file
     my $pipe = $host->pipe_command(
         { COMMAND => ['apt-ftparchive', '-q=2', '-c', $tmpfilename, 'release', $dummy_archive_dir],
-          USER => $self->get_conf('USER'),
+          USER => $self->get_conf('USERNAME'),
           PRIORITY => 0,
           DIR => '/'});
     if (!defined($pipe)) {
